Lei.BatchAnalyzer (LowEndInsight v0.9.1)

Copy Markdown View Source

Batch SBOM analysis engine.

Analyzes lists of dependencies with parallel cache lookups, targeting <500ms for 50 dependencies when mostly cached.

Summary

Functions

Analyze a batch of dependencies.

Functions

analyze(dependencies, opts \\ [])

Analyze a batch of dependencies.

Each dependency should be a map with "ecosystem", "package", and "version" keys. Returns a summary with cached results and pending jobs for cache misses.