Lei.Rules.CopilotTemplate (LowEndInsight v0.9.1)

Copy Markdown View Source

Renders the GitHub Copilot instructions file for LowEndInsight dependency risk awareness.

Summary

Functions

Renders the Copilot instructions template with the given threshold values.

Functions

render(thresholds)

@spec render(map()) :: String.t()

Renders the Copilot instructions template with the given threshold values.