Lei.Rules.CursorTemplate (LowEndInsight v0.9.1)

Copy Markdown View Source

Renders the Cursor IDE rule file (.mdc) for LowEndInsight dependency risk awareness.

Summary

Functions

Renders the Cursor rules template with the given threshold values.

Functions

render(thresholds)

@spec render(map()) :: String.t()

Renders the Cursor rules template with the given threshold values.