Scanner scans for Cargo/Rust dependencies to run analysis on.
Summary
Functions
analyze_dependencies: Run LEI analysis on a list of dependencies. Returns list of analysis reports.
get_repo_url: Given a crate name and source info, determine the repository URL. For crates.io packages, queries the API. For git sources, uses the URL directly.
scan: takes in project types map with cargo paths and returns the dependencies mapped to their analysis and the number of dependencies.
Functions
analyze_dependencies: Run LEI analysis on a list of dependencies. Returns list of analysis reports.
get_repo_url: Given a crate name and source info, determine the repository URL. For crates.io packages, queries the API. For git sources, uses the URL directly.
@spec scan(boolean(), map()) :: {[any()], non_neg_integer()}
scan: takes in project types map with cargo paths and returns the dependencies mapped to their analysis and the number of dependencies.