Exports LEI analysis reports as cache snapshot files.
Generates two files in an export directory:
manifest.json- Metadata about the cache snapshotcache.jsonl.gz- Gzipped JSONL of analysis reports
These files can then be packaged as an OCI artifact via Lei.Cache.OCI.
Summary
Functions
Exports a list of analysis reports to the given directory.
Reads analysis reports from a JSONL file (plain or gzipped).
Converts a list of reports to newline-delimited JSON (JSONL).
Functions
Exports a list of analysis reports to the given directory.
Each report should be a map as returned by AnalyzerModule.analyze/3.
Creates manifest.json and cache.jsonl.gz in output_dir.
Reads analysis reports from a JSONL file (plain or gzipped).
Converts a list of reports to newline-delimited JSON (JSONL).